v0.1.6 (February 26, 2023)
----------------------------

This is a minor change performed from ``v0.1.6-alpha`` and adaptations, bug fixes and improvements for issues identified.  


Adaptations and Features 
~~~~~~~~~~~~~~~~~~~~~~~~~~

- |Feature| Add :func:`watex.utils.get2dtensor` for getting the tensor from 3D to 2D after signal 
  recovery with :meth:`watex.methods.Processing.zrestore`. 

- |Feature| Add skew visualization: :func:`watex.utils.plot_skew` for phase-sensitive visualization; :meth:`watex.view.TPlot.plotSkew` 
  for a consistent plot for phase-sensitive visualization

- |Enhancement| Visualizes the phase tensors with  :meth:`watex.view.TPlot.plot_phase_tensors`. 

- |Feature| Load Huayuan :term:`SEG`- :term:`EDI` datasets from :func:`watex.datasets.load_huayuan`. 

- |Enhancement| It is no longer useful to set the keyword parameter ``option``  of  :meth:`watex.methods.Processing.getValidTensors` to ``None`` every times to get the valid tensors.  The default implementation is 
  henceforth set to ``None`` and returns the valid tensors after the quality control ( See :meth:`watex.methods.Processing.qc` ). So, to export the valid tensors as :term:`EDI` files, 
  set explicitly the ``option`` to ``'write'`` instead.  For instance::

  >>> import watex as wx 
  >>> edis = wx.fetch_data ('huayuan', samples=45, as_frame =True, clear_cache=True ).edi
  >>> Z = wx.EMProcessing().fit(edis).getValidTensors (tol =0.3 ) # outputs valid 3D new Impedance tensors with  >=70% assertion of data representativity 
  >>> wx.EMProcessing().fit(edis).getValidTensors (tol =0.3 , option ='write') # export tensors.  

- |Enhancement| Enable the skew dimensional plot with the combination with :class:`watex.methods.Processing` and :func:`watex.view.plot2d`. 

- |Feature| Add new features with strike (:func:`watex.utils.plot_strike`) and confidence plots in the :term:`EDI` data 
  (:func:`watex.utils.plot_confidence_in`). The latter is useful to know the signals to recover and useless
  frequencies for deletion. 
  
Bug fixes 
~~~~~~~~~~

- |Fix| Warn user when DC-parameters can be computed because of constraints (fixed ``AttributeError``
  in :meth:`watex.methods.ResistivityProfiling.summary`)

- |Fix| add ``openpyxl`` as the hard dependency at the initiliation of the package to avoid crashing 
  when :mod:`watex.geology` module is called. 

- |Fix| Bug fixed when calling the fine-tuned models from :class:`watex.GridSearchMultiple` objet. Henceforth models 
  can be fetched as :class:`watex.utils.box.Boxspace` object that saves the estimator parameters, model names and 
  cv results. 
  
- |Fix| when building the :code:`watex` documentation, :meth:`watex.view.TPlot.plot_phase_tensors` calls MTpy imaging 
  module which call matplotlib in turn to update MTpy propers colors. However, it does not recognize ``cmap_d`` in 
  the ``cmapdict.update(cm.cmap_d)`` of code line 252 by showing and ``AttributeError`` like below:

  .. code-block:: default 

      Unexpected failing examples:
      
      /home/docs/checkouts/readthedocs.org/user_builds/watex/checkouts/master/examples/methods/plot_phase_tensors.py failed leaving traceback:
      Traceback (most recent call last):
        ...
           import mtpy.imaging.mtcolors as mtcl
        File "/home/docs/checkouts/readthedocs.org/user_builds/watex/envs/master/lib/python3.10/site-packages/mtpy/imaging/mtcolors.py", line 252, in <module>
           cmapdict.update(cm.cmap_d)
        File "/home/docs/checkouts/readthedocs.org/user_builds/watex/envs/master/lib/python3.10/site-packages/matplotlib/_api/__init__.py", line 224, in __getattr__
           raise AttributeError(
        AttributeError: module 'matplotlib.cm' has no attribute 'cmap_d'

  To fix it and let the doc building correctly with the latest version of matplotlib, uncomment the examples in gallery 
  ``methods.plot_phase_tensors.py`` :meth:`watex.view.TPlot.plot_phase_tensors` object `tplot` rather than using the 
  matplotlib colormaps instead since  MTpy proper colors don't work. An error will raise in both case...

- |Fix| Bug fixed with :meth:`watex.view.TPlot.plot_phase_tensors` using Matplotlib version 3.5.3 max. The latest version will yield an 
  attribute error due to the use of `cmap_d` in updating MTpy proper colors ``cmapdict.update(cm.cmap_d)``. 
  
- |Fix| Bug fixed in loading the :func:`watex.models.displayCVTables` from :class:`watex.models.GridSearchMultiple`.  Use try -except instead to accept the 
  fine-tuned models directly from :class:`watex.exlib.GridSearchCV` or  :class:`watex.models.GridSearchMultiple` or :class:`watex.models.GridSearch`  
  
- |Fix| Bug fixed in the new implementation of quality control :meth:`watex.methods.Processing.qc`. No need to supply :term:`EDI` media-files or ``ediObjs`` as a positional argument since ``inspect`` 
  is used to assert whether the :class:`watex.methods.Processing` is called yet.
  


  
